package com.rwk.system.mapper;

import java.util.List;
import com.rwk.system.domain.RwkStaffInformation;
import com.rwk.system.domain.RwkFamilyMember;

/**
 * 人员信息Mapper接口
 *
 * @author rick
 * @date 2024-11-25
 */
public interface RwkStaffInformationMapper
{
    /**
     * 查询人员信息
     *
     * @param id 人员信息主键
     * @return 人员信息
     */
    public RwkStaffInformation selectRwkStaffInformationById(Long id);

    /**
     * 查询人员信息列表
     *
     * @param rwkStaffInformation 人员信息
     * @return 人员信息集合
     */
    public List<RwkStaffInformation> selectRwkStaffInformationList(RwkStaffInformation rwkStaffInformation);

    /**
     * 新增人员信息
     *
     * @param rwkStaffInformation 人员信息
     * @return 结果
     */
    public int insertRwkStaffInformation(RwkStaffInformation rwkStaffInformation);

    /**
     * 修改人员信息
     *
     * @param rwkStaffInformation 人员信息
     * @return 结果
     */
    public int updateRwkStaffInformation(RwkStaffInformation rwkStaffInformation);

    /**
     * 删除人员信息
     *
     * @param id 人员信息主键
     * @return 结果
     */
    public int deleteRwkStaffInformationById(Long id);

    /**
     * 批量删除人员信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRwkStaffInformationByIds(String[] ids);

    /**
     * 批量删除家庭成员
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRwkFamilyMemberByFamilyMemberCodes(String[] ids);

    /**
     * 批量新增家庭成员
     *
     * @param rwkFamilyMemberList 家庭成员列表
     * @return 结果
     */
    public int batchRwkFamilyMember(List<RwkFamilyMember> rwkFamilyMemberList);


    /**
     * 通过人员信息主键删除家庭成员信息
     *
     * @param id 人员信息ID
     * @return 结果
     */
    public int deleteRwkFamilyMemberByFamilyMemberCode(Long id);
}
